@@ -12,7 +12,13 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-#[derive(Debug, Clone)]
+//! Different credential types that used to signing requests.
+
+use std::fmt::Debug;
+use std::fmt::Display;
+use std::fmt::Formatter;
+
+#[derive(Clone)]
 pub enum Credential {
     /// Plain refers to no credential has been provided, fallback to services'
     /// default logic.
@@ -34,6 +40,30 @@ pub enum Credential {
     Token(String),
 }
 
+// Credential has sensitive data, we should not print it out in anyway.
+impl Debug for Credential {
+    fn fmt(&self, f: &mut Formatter<'_>) -> std::fmt::Result {
+        match self {
+            Credential::Plain => write!(f, "Credential::Plain"),
+            Credential::Basic { .. } => write!(f, "Credential::Basic"),
+            Credential::HMAC { .. } => write!(f, "Credential::HMAC"),
+            Credential::Token(_) => write!(f, "Credential::Token"),
+        }
+    }
+}
+
+// Credential has sensitive data, we should not print it out in anyway.
+impl Display for Credential {
+    fn fmt(&self, f: &mut Formatter<'_>) -> std::fmt::Result {
+        match self {
+            Credential::Plain => write!(f, "plain"),
+            Credential::Basic { .. } => write!(f, "basic"),
+            Credential::HMAC { .. } => write!(f, "hmac"),
+            Credential::Token(_) => write!(f, "token"),
+        }
+    }
+}
+
 impl Credential {
     pub fn basic(username: &str, password: &str) -> Credential {
         if username.is_empty() && password.is_empty() {
