@@ -1,4 +1,4 @@
-// Copyright 2021 Datafuse Labs.
+// Copyright 2022 Datafuse Labs.
 //
 // Licensed under the Apache License, Version 2.0 (the "License");
 // you may not use this file except in compliance with the License.
@@ -12,11 +12,13 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-/// Every mod represents a service.
-///
-/// In order to implement a service, we need the following things:
-///
-/// - Builder: responsible for building the service backend.
-/// - Backend: the service backend which implements the `Accessor` trait.
+//! Providing specific services support.
+//!
+//! In order to implement a service, we need the following things:
+//!
+//! - Builder: responsible for building the service backend.
+//! - Backend: the service backend which implements the [`Accessor`][crate::Accessor] trait.
+
 pub mod fs;
+pub mod memory;
 pub mod s3;
